## Figure 2
rm(list=ls())

par(mfrow=c(1,2))


prynoproduct<-function(b0,b1,b2,x,z){

temp<-exp(b0+b1*x+b2*z)/(1+exp(b0+b1*x+b2*z))
return(temp)

}

dydxnoproduct<-function(b0,b1,b2,x,z){

xx<-x+.0005
prytwo<-prynoproduct(b0,b1,b2,xx,z)
xx<-x-.0005
pryone<-prynoproduct(b0,b1,b2,xx,z)
DYDX<-(prytwo-pryone)/(.001)
return(DYDX)

}

pryproduct<-function(b0,b1,b2,x,z){

temp<-exp(b0+b1*x+b2*z-0.30*x*z)/(1+exp(b0+b1*x+b2*z-0.30*x*z))
return(temp)

}

dydxproduct<-function(b0,b1,b2,x,z){

xx<-x+.0005
prytwo<-pryproduct(b0,b1,b2,xx,z)
xx<-x-.0005
pryone<-pryproduct(b0,b1,b2,xx,z)
DYDX<-(prytwo-pryone)/(.001)
return(DYDX)

}

x<-seq(from=0, to=8, by=.1)
plotone<-prynoproduct(-4,1,1,x,0)
plot(x,plotone, type="l", main=c("Illustrative Logit Model","Without Product Term"), xlab=expression(X[1]), ylab=expression(Pr(Y)), ylim=c(0,1))
plottwo<-prynoproduct(-4,1,1,x,1)
lines(x,plottwo, lty=2)
plotthree<-prynoproduct(-4,1,1,x,2)
lines(x, plotthree, lty=3)
legend("topleft", legend=c(expression(X[2]==0),expression(X[2]==1),expression(X[2]==2)), lty=c(1,2,3))


x<-seq(from=0, to=8, by=.1)
plotone<-pryproduct(-4,1,1,x,0)
plot(x,plotone, type="l", main=c("Illustrative Logit Model","With Product Term"), xlab=expression(X[1]), ylab=expression(Pr(Y)), ylim=c(0,1))
plottwo<-pryproduct(-4,1,1,x,1)
lines(x,plottwo, lty=2)
plotthree<-pryproduct(-4,1,1,x,2)
lines(x, plotthree, lty=3)
legend("topleft", legend=c(expression(X[2]==0),expression(X[2]==1),expression(X[2]==2)), lty=c(1,2,3))


## Compute Marginal Effects for use in Text (Associated with Fig 2)

dydxproduct(-4,1,1,6,0)
dydxnoproduct(-4,1,1,6,0)

dydxproduct(-4,1,1,6,2)
dydxnoproduct(-4,1,1,6,2)

dydxproduct(-4,1,1,4,0)
dydxproduct(-4,1,1,4,1)
dydxproduct(-4,1,1,4,2)

dydxproduct(-4,1,1,4,0)
dydxproduct(-4,1,1,4,1)
dydxproduct(-4,1,1,4,2)

dydxproduct(-4,1,1,1,0)
dydxproduct(-4,1,1,1,1)
dydxproduct(-4,1,1,1,2)


dydxproduct(-4,1,1,7,0)
dydxproduct(-4,1,1,7,1)
dydxproduct(-4,1,1,7,2)


## Three variable logit model example from text

rm(list=ls())

prythree<-function(b1,b2,b3,x,z,w){

temp<-exp(b1*x+b2*z+b3*w)/(1+exp(b1*x+b2*z+b3*w))
return(temp)

}

dydxthree<-function(b1,b2,b3,x,z,w){

xx<-x+.0005
prytwo<-prythree(b1,b2,b3,xx,z,w)
xx<-x-.0005
pryone<-prythree(b1,b2,b3,xx,z,w)
DYDX<-(prytwo-pryone)/(.001)
return(DYDX)

}


prythree(1,0.5,0.25,0,0,0)
dydxthree(1,0.5,0.25,0,0,0)
prythree(1,0.5,0.25,0,4.5,0)
dydxthree(1,0.5,0.25,0,4.5,0)
prythree(1,0.5,0.25,0,0,9)
dydxthree(1,0.5,0.25,0,0,9)



## Figure 3 (3-D Logit Plots With and Without Compression)

rm(list=ls())

par(mfrow=c(1,2), cex=0.5,cex.main=2)

prynoproduct<-function(b0,b1,b2,x,z){

temp<-exp(b0+b1*x+b2*z)/(1+exp(b0+b1*x+b2*z))
return(temp)

}

dydxnoproduct<-function(b0,b1,b2,x,z){

xx<-x+.0005
prytwo<-prynoproduct(b0,b1,b2,xx,z)
xx<-x-.0005
pryone<-prynoproduct(b0,b1,b2,xx,z)
DYDX<-(prytwo-pryone)/(.001)
return(DYDX)

}

r<-seq(from=0, to=8, by=0.5)
X<-rep(r, length(r))
Z<-rep(r, 1, each=length(r))

Y<-prynoproduct(-8,1,1,X,Z)

persp(r,r,matrix(Y,nrow=length(r)),theta=25, phi=20, main="With Compression", xlab="", ylab="", zlab="", zlim=c(0,1), box=T, axes=T, ticktype="detailed" )


r<-seq(from=0, to=8, by=0.5)
X<-rep(r, length(r))
Z<-rep(r, 1, each=length(r))

Y<-prynoproduct(-1,.125,.125,X,Z)

persp(r,r,matrix(Y,nrow=length(r)),theta=25, phi=20, main="	Without Compression", xlab="", ylab="", zlab="", zlim=c(0.2,0.8), box=T, axes=T, ticktype="detailed" )

dydxnoproduct(-1,.125,.125,0,0)
dydxnoproduct(-1,.125,.125,8,0)
dydxnoproduct(-1,.125,.125,0,8)
dydxnoproduct(-1,.125,.125,8,8)